/*global define, window, facebook*/

define([
    'testsuite/qunit',
    'jquery',
    'de_epages/externalcontent/gadgetdialog/facebook-view',

    '$ready!'
], function (QUnit, $, FacebookView) {
    QUnit.module('de_epages/externalcontent/ui/facebook-view', {
        setup: function () {
            window.element = null;

            window.FB = {
                XFBML : {
                    parse : function (_element) {
                        window.element = _element;
                    }
                }
            };

            $.ajax = function (o) {
                return {done: function (_func) {_func(); }};
            };

            window.facebook = new FacebookView();
            $('#qunit-fixture').append(facebook.render().el);
        },
        teardown: function () {
            $('#qunit-fixture').empty();
        }
    });

    QUnit.test('Test facebook view methods', 1, function () {
        $.each(['onSelect'], function (i, method) {
            QUnit.equal(
                $.isFunction(facebook[method]),
                true,
                method + ' is a method of facebook-view'
            );
        });
    });

    QUnit.asyncTest('Test facebook button settings', 13, function () {
        var preview = $('.PreviewNode.SocialWeb').children();

        QUnit.equal(
            $('#ep-gadgets-facebook').length,
            1,
            'Create facebook view'
        );

        QUnit.equal(
            $('fieldset[name="box"]').attr('disabled'),
            'disabled',
            'Option *button* is active, disable box options'
        );

        QUnit.deepEqual(
            facebook.gOptions,
            {action: "like", layout: "standard", showFaces: true, type: "button"},
            "Get default options"
        );

        QUnit.equal(
            preview.data('action'),
            'like',
            'Default action is *like*'
        );

        QUnit.equal(
            preview.data('layout'),
            'standard',
            'Default layout is *standard*'
        );

        QUnit.equal(
            preview.data('showFaces'),
            true,
            '*Show faces* by default'
        );

        $('#showFaces').trigger('click');
        $('#action').val('recommend').trigger('change');
        $('#layout').val('button_count').trigger('change');

        setTimeout(function () {
            preview = $('.PreviewNode.SocialWeb').children();

            QUnit.deepEqual(
                facebook.gOptions,
                {"type": "button", "action": "recommend", "layout": "button_count", "showFaces": false},
                "Get options after change"
            );

            QUnit.equal(
                preview.data('showFaces'),
                false,
                'Do not *Show faces*'
            );

            QUnit.equal(
                preview.data('action'),
                'recommend',
                'Change action to *recommend*'
            );

            QUnit.equal(
                preview.data('layout'),
                'button_count',
                'Change layout to *button_count*'
            );

            $('#layout').val('box_count').trigger('change');


            setTimeout(function () {
                preview = $('.PreviewNode.SocialWeb').children();

                QUnit.equal(
                    preview.data('layout'),
                    'box_count',
                    'Change layout to *box_count*'
                );

                QUnit.equal(
                    $('#showFaces').attr('disabled'),
                    'disabled',
                    '*Show faces* is disabled for layout *box_count*'
                );

                $('#layout').val('standard').trigger('change');

                setTimeout(function () {
                    QUnit.equal(
                        $('#showFaces').attr('disabled'),
                        undefined,
                        '*Show faces* is enabled for layout *standard*'
                    );

                    QUnit.start();
                }, 500);
            }, 500);
        }, 500);
    });

    QUnit.asyncTest('Test facebook box settings', 15, function () {
        QUnit.equal(
            $('#ep-gadgets-facebook').length,
            1,
            'Create facebook view'
        );

        $('fieldset[name="type"] input[value="box"]').trigger('click');

        setTimeout(function () {
            QUnit.equal(
                $('fieldset[name="button"]').attr('disabled'),
                'disabled',
                'Option *box* is active, disable button options'
            );

            var preview = $('.PreviewNode.SocialWeb').children();

            $('#url').val('http://www.epages.com/de/').trigger('change');

            QUnit.deepEqual(
                facebook.gOptions,
                {"type": "box", "url": "http://www.epages.com/de/", "color": "light", "showFaces": true, "showStream": false, "showHeader": false, "width": "290", "height": ""},
                "Get default options"
            );

            QUnit.equal(
                preview.hasClass('fb-like-box'),
                true,
                'Preview node has class *fb-like-box*'
            );

            QUnit.equal(
                preview.data('width'),
                290,
                'Default width is 290'
            );

            QUnit.equal(
                preview.data('colorscheme'),
                'light',
                'Default colorscheme is *light*'
            );

            QUnit.equal(
                preview.data('showFaces'),
                true,
                '*Show faces* by default'
            );

            QUnit.equal(
                preview.data('stream'),
                false,
                'Do not show *activities* by default'
            );

            QUnit.equal(
                preview.data('header'),
                false,
                'Do not show *header* by default'
            );

            QUnit.equal(
                preview.data('href'),
                false,
                'Use *http://www.epages.com/de/* as url'
            );

            // Change settings
            $('fieldset[name="box"] #showFaces').trigger('click');
            $('#showStream').trigger('click');
            $('#showHeader').trigger('click');
            $('#width').val('300').trigger('change');
            $('#height').val('500').trigger('change');

            setTimeout(function () {
                preview = $('.PreviewNode.SocialWeb').children();

                QUnit.equal(
                    preview.data('showFaces'),
                    false,
                    'Do not *Show faces*'
                );

                QUnit.equal(
                    preview.data('stream'),
                    true,
                    'Show *activities* in stream'
                );

                QUnit.equal(
                    preview.data('header'),
                    true,
                    'Show *header*'
                );

                QUnit.equal(
                    preview.data('width'),
                    300,
                    'Change width to 300px'
                );

                QUnit.equal(
                    preview.data('height'),
                    500,
                    'Change height to 500px'
                );

                QUnit.start();

            }, 500);
        }, 500);
    });
});