define("de_epages/spreedly/ui/checkoutconfirmation", [
    "jquery",
    "de_epages/spreedly/ui/checkoutlifecycle",
    "spreedlyexpress2",
    "ep/ajax",
    "ep/fn/busy",
    "$ready!"
], function ($, checkoutlifecycle) {

    return function(
    SpreedlyEnvironmentKey,
    BasketTotalAmount,
    ShopName,
    BasketId
    ){
        var SpeedlyExpressWidgetDisplayOptions = {
            "amount": BasketTotalAmount,
            "company_name": ShopName
        };

        function isValidBasketForm() {
            ep("form#BasketForm").trigger("validate");
            return (ep("form#BasketForm .ui-invalid").length === 0);
        }

        function getParameterValue(parameterName) {
            var result = null;
            var tmp = [];
            var items = location.search.substr(1).split("&");
            for (var index = 0; index < items.length; index++) {
                tmp = items[index].split("=");
                if (tmp[0] === parameterName) result = decodeURIComponent(tmp[1]);
            }
            return result;
        }

        function recoverMarkedCheckboxes() {
            if ($('#AcceptTAC').length) {
                $('#AcceptTAC').prop("checked", true);
            }
            if ($('#AcceptCustomerInformation').length) {
                $('#AcceptCustomerInformation').prop("checked", true);
            }

            if (getParameterValue("RatingInvitationFlag") === "true") {
                $('#IsRatingInvitationAllowed').prop("checked", true);
            }
        }

        function handleSpreedlyCallback() {
            if (getParameterValue("transaction_token") && "ViewMultiCheckoutConfirmation" === getParameterValue("ViewAction")) {
                ep("body").busy("show");
                recoverMarkedCheckboxes();
                document.forms["BasketForm"].submit();
            } else {
                onBuyButtonConfirmation();
            }
        }

        function onCheckoutError(Error) {
            var BasketForm = document.forms["BasketForm"];
            if(Error && Error.Name) {
                ep(BasketForm).append("<input type='hidden' value='" + Error.Name + "' name='ErrorName'>");
            }
            if(Error && Error.Reason) {
                ep(BasketForm).append("<input type='hidden' value='" + Error.Reason + "' name='ErrorReason'>");
            }
            BasketForm.submit();
        }

        function onCheckoutSuccess() {
            document.forms["BasketForm"].submit();
        }

        function onSuccessfulPurchaseResponse(Transaction) {
            if (Transaction.state === "succeeded") {
                return onCheckoutSuccess();
            } else if (Transaction.state === "error") {
                onCheckoutError({
                    "Name": "Purchase",
                    "Reason": "CardDeclined",
                });
            } else if (Transaction.state === "pending" && Transaction.required_action === "redirect") {
                on3DS1Fallback(Transaction);
            } else if (Transaction.state === "pending") {
                checkoutlifecycle(
                    Transaction.state,
                    Transaction.token,
                    Transaction.required_action,
                    Transaction.device_fingerprint_form,
                    Transaction.checkout_form,
                    Transaction.checkout_url,
                    BasketId,
                    onCheckoutSuccess,
                    onCheckoutError
                );
            } else {
                onCheckoutError({
                    "Name": "Purchase",
                    "Reason": "UnknownError",
                });
            }
        }

        function on3DS1Fallback(Transaction) {
            ep("body").busy("show");
            if (Transaction.checkout_form) {
                $(Transaction.checkout_form).appendTo("body").submit();
            } else if (Transaction.checkout_url) {
                window.location.replace(Transaction.checkout_url);
            } else {
                onCheckoutError({
                    "Name": "Purchase",
                    "Reason": "UnknownError",
                });
            }
        }

        function getPurchaseRequestData() {
            var SpreedlyWidgetFullscreenSize = '05';
            var requestData = {
                "ChangeAction": "MakeSpreedlyPurchase",
                "ObjectID": BasketId,
                "SpreedlyBrowserInfo": Spreedly.ThreeDS.serialize(SpreedlyWidgetFullscreenSize)
            };
            if ($('#IsRatingInvitationAllowed').prop("checked")) {
                requestData["IsRatingInvitationAllowed"] = 1;
            }
            return requestData;
        }

        function onBuyButtonClick() {
            if (!isValidBasketForm()) {
                ep("body").busy("hide");
                return false;
            }
            var purchaseRequestData = getPurchaseRequestData();

            ep.ajax({
                "data" : purchaseRequestData,
                "type" : "post",
                "dataType" : "json"
            }).done(function(response) {
                if(!response.Error && response.Transaction){
                    onSuccessfulPurchaseResponse(response.Transaction);
                } else {
                    onCheckoutError(response.Error);
                }
            }).fail(function( response ){
                onCheckoutError({
                    "Name": "Purchase",
                    "Reason": "ConnectionError",
                });
            });
        }

        function onBuyButtonConfirmation() {
            $('button.SubmitButton').on('click.submitSpreedlyPurchase', function(event) {
                event.stopPropagation();
                event.preventDefault();
                ep("body").busy("show");
                onBuyButtonClick();
                return false;
            });
            SpreedlyExpress.init(SpreedlyEnvironmentKey, SpeedlyExpressWidgetDisplayOptions);
            SpreedlyExpress.onInit(function(){
                ep("div.Confirm-Order button.SubmitButton").prop("disabled", false);
            });
        }

        $("div.Confirm-Order button.SubmitButton").prop("disabled", true);
        $(document).ready(function() {
            handleSpreedlyCallback();
        });
    };
});
