/**
 * Module to handle different video actions.
 */

/*
 * @copyright       © Copyright 2006-2019, epages GmbH, All Rights Reserved.
 *
 * @module          ep.fn.video
 */

define("ep/fn/video", [
    "jquery",
    "ep",
    "$tmpl!ep/fn/video-iframe",

    "jquery/tmpl"
], function($, ep, tmplVideoIframe) {
    // parses a youtube url
    // returns
    // Object - url: video url
    //        - src: image url
    //        - id: video id
    //        - ext: video url extensions (default: '')
    var parseYoutubeUrl = function(url) {
        var regex = /^.*(?:(?:youtu\.be\/|v\/|vi\/|u\/\w\/|embed\/)|(?:(?:watch)?\?v(?:i)?=|&v(?:i)?=))([^#&?]+)(.*)/,
            match = regex.exec(url),
            ret = {
              id: '',
              ext: ''
            };

        // if regular expression matches
        if (match !== null) {
            ret.id = match[1];
            ret.ext = match[2] ? match[2] : '';
        }

        return ret;
      };

    return {
        // returns a video iframe html fragment for youtube
        youtubeIframe: function(options) {
            // get url from options parameter or default value ("Willkommen bei ePages" video)
            var url = (options && options.url) ? options.url : 'https://youtu.be/ouWbLob0f1o',
                defaults = {},
                renderedTemplate;

            if (options.embedurl) {
                defaults.embedurl = options.embedurl;
            // if id and extension are handed over in options parameter
            } else if (options.id && options.ext) {
                defaults.id = options.id;
                defaults.ext = options.ext;
            // parse from url
            } else {
                defaults = $.extend(defaults, parseYoutubeUrl(url));
            }

            defaults.url = url;
            defaults.name = options.name || 'youtube';

            // extend options parameter with object from parsed youtube url
            options = $.extend({
                name: 'youtube',
                url: url,
                embedurl: false,
                id: '',
                ext: ''
            }, defaults);

            // render template
            renderedTemplate = tmplVideoIframe([options]);

            return renderedTemplate;
        },

        // returns a video iframe html fragment for vimeo
        vimeoIframe: function(options) {
            // return rendered template
            return tmplVideoIframe([options]);
        }
    };
});